@@ -4,13 +4,13 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '1.000002';
+our $VERSION = '1.000003';
 
 use 5.010000;
 
 use Math::Int128 qw( uint128 );
-use MaxMind::DB::Metadata;
-use MaxMind::DB::Reader 1.000000;
+use MaxMind::DB::Metadata 0.040001;
+use MaxMind::DB::Reader 1.000012;
 use MaxMind::DB::Types qw( Int );
 
 use Moo;
@@ -50,16 +50,15 @@ sub _data_for_address {
     return $self->__data_for_address( $self->_mmdb(), @_ );
 }
 
-sub _read_node {
-    my $self = shift;
+sub iterate_search_tree {
+    my $self          = shift;
+    my $data_callback = shift;
+    my $node_callback = shift;
 
-    return $self->__read_node( $self->_mmdb(), @_ );
-}
-
-sub _get_entry_data {
-    my $self = shift;
-
-    return $self->__get_entry_data( $self->_mmdb(), @_ );
+    return $self->_iterate_search_tree(
+        $self->_mmdb, $data_callback,
+        $node_callback
+    );
 }
 
 sub _build_mmdb {
@@ -123,7 +122,7 @@ MaxMind::DB::Reader::XS - Fast XS implementation of MaxMind DB reader
 
 =head1 VERSION
 
-version 1.000002
+version 1.000003
 
 =head1 SYNOPSIS
 
@@ -197,7 +196,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by MaxMind, Inc..
+This software is Copyright (c) 2016 by MaxMind, Inc.
 
 This is free software, licensed under:
 
